sqltriples.Adapters.pysqlite2Adapter

Package sqltriples :: Module Adapters :: Class pysqlite2Adapter |
[show private | hide private]
[frames | no frames]

## Class pysqlite2Adapter

    Adapter --+
              |
             pysqlite2Adapter

Method Summary
| `query_next_bnode_id(self, cursor, sequence_name)`
Inherited from Adapter
| ``__init__`(self, connection)`
| ``delete_index`(self, cursor, table_name)`
| ``delete_sequence`(self, cursor, sequence_name)`
| ``delete_table`(self, cursor, table_name)`
| ``init_index`(self, cursor, table_name)`
| ``init_sequence`(self, cursor, sequence_name)`
| ``init_table`(self, cursor, table_name)`

Class Variable Summary
`str` | `paramstyle` = `'qmark'`
Inherited from Adapter
`int` | `supports_in_tuples` = 0

Class Variable Details

    ### paramstyle Type: `str` Value:
        'qmark'

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net